Documentation
¶
Overview ¶
Package provision provides interfaces that need to be satisfied in order to implement a new iaas on tsuru.
Package provision provides interfaces that need to be satisfied in order to implement a new iaas on tsuru.
Index ¶
Constants ¶
const UserData = `#!/bin/bash
curl -sL https://raw.github.com/tsuru/now/master/run.bash | bash -s -- --docker-only
`
Variables ¶
This section is empty.
Functions ¶
func RegisterIaasProvider ¶
Types ¶
type IaaS ¶
type IaaS interface {
// Called when tsuru is creating a Machine.
CreateMachine(params map[string]string) (*Machine, error)
// Called when tsuru is destroying a Machine.
DeleteMachine(m *Machine) error
}
Every Tsuru IaaS must implement this interface.
type Machine ¶
type Machine struct {
Id string `bson:"_id"`
Iaas string
Status string
Address string
CreationParams map[string]string
}
func CreateMachineForIaaS ¶
func FindMachineByAddress ¶
func FindMachineById ¶
func ListMachines ¶
func (*Machine) FormatNodeAddress ¶
Click to show internal directories.
Click to hide internal directories.