Documentation
¶
Overview ¶
Package router provides interfaces that need to be satisfied in order to implement a new router on tsuru.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrRouteNotFound = errors.New("Route not found")
Functions ¶
Types ¶
type Router ¶
type Router interface {
AddBackend(name string) error
RemoveBackend(name string) error
AddRoute(name, address string) error
RemoveRoute(name, address string) error
SetCName(cname, name string) error
UnsetCName(cname, name string) error
Addr(name string) (string, error)
// Swap change the router between two backends.
Swap(string, string) error
// Routes returns a list of routes of a backend.
Routes(name string) ([]string, error)
}
Router is the basic interface of this package. It provides methods for managing backends and routes. Each backend can have multiple routes.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package hipache provides a router implementation that store routes in Redis, as specified by Hipache (https://github.com/dotcloud/hipache).
|
Package hipache provides a router implementation that store routes in Redis, as specified by Hipache (https://github.com/dotcloud/hipache). |
Click to show internal directories.
Click to hide internal directories.